"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// tslint:disable no-require-imports
const loopbackConnector = require("loopback-connector");
const _dbg = require("debug");
/*
 * SQLite3 connector for LoopBack
 */
const SqlDatabase_1 = require("sqlite3orm/SqlDatabase");
const utils_1 = require("./utils");
const debug = _dbg('loopback:connector:sqlite3x:connector');
const SQLITE3_CONNECTOR_NAME = 'sqlite3x';
// TODO: type for SQLConnector is missing
class Sqlite3Connector extends loopbackConnector.SQLConnector {
    get sqldb() {
        return this._sqldb;
    }
    constructor(settings) {
        super(SQLITE3_CONNECTOR_NAME, settings);
        this._sqldb = new SqlDatabase_1.SqlDatabase();
        if (this.settings.debug) {
            debug(`${SQLITE3_CONNECTOR_NAME} settings: %j`, this.settings);
            SqlDatabase_1.SqlDatabase.verbose();
        }
    }
    /**
     *
     * connect to Sqlite3 database
     *
     * @callback [cb] The callback function
     */
    connect(cb) {
        this.connecting =
            utils_1.promisify(this._sqldb.open(this.settings.file, this.settings.mode), cb);
        return this.connecting;
    }
    /**
     *
     * disconnect from Sqlite3 database
     *
     * @callback [cb] The callback function
     */
    disconnect(cb) {
        return utils_1.promisify(this._sqldb.close(), cb);
    }
    ping(cb) {
        return utils_1.promisify(this._sqldb.getUserVersion());
    }
}
exports.Sqlite3Connector = Sqlite3Connector;
function initialize(dataSource, cb) {
    const connectorSettings = {};
    connectorSettings.file =
        (dataSource.settings && dataSource.settings.file) || SqlDatabase_1.SQL_MEMORY_DB_SHARED;
    connectorSettings.mode =
        (dataSource.settings && dataSource.settings.mode) || SqlDatabase_1.SQL_OPEN_DEFAULT;
    connectorSettings.debug =
        (dataSource.settings && !!dataSource.settings.debug) || !!debug.enabled;
    dataSource.connector =
        new Sqlite3Connector(connectorSettings);
    dataSource.connector.dataSource = dataSource;
    /* istanbul ignore else */
    if (cb) {
        dataSource.connector.connect(cb);
    }
}
exports.initialize = initialize;
exports.name = SQLITE3_CONNECTOR_NAME;
//# sourceMappingURL=sqlite3-connector.js.map